# [GAY 🏳️‍🌈](https://ms-jpq.github.io/gay)

Colour your text / terminal to be more gay.

Gayer version of [`lolcat`](https://github.com/busyloop/lolcat)

## Get Gay

`pip install gay`

## Show me

### Text

```sh
echo 'message' | gay
```

![help.png](https://raw.githubusercontent.com/ms-jpq/gay/%3C3/preview/help.png)

![dog.png](https://raw.githubusercontent.com/ms-jpq/gay/%3C3/preview/dog.png)

![anthem.png](https://raw.githubusercontent.com/ms-jpq/gay/%3C3/preview/anthem.png)

### Flag

```sh
gay --flag
```

Unlike the demo, it shows 1 flag and 1 flag only.

![flags.gif](https://raw.githubusercontent.com/ms-jpq/gay/%3C3/preview/flags.gif)
